@@ -24,6 +24,7 @@ var KNOWN_ARGS = {'alternate-exchange':        {'short': 'AE',  'type': 'string'
                   'x-dead-letter-exchange':    {'short': 'DLX', 'type': 'string'},
                   'x-dead-letter-routing-key': {'short': 'DLK', 'type': 'string'},
                   'x-queue-master-locator':    {'short': 'ML', 'type': 'string'},
+                  'x-queue-leader-locator':    {'short': 'LL', 'type': 'string'},
                   'x-max-priority':            {'short': 'Pri', 'type': 'int'},
                   'x-single-active-consumer':  {'short': 'SAC', 'type': 'boolean'}};
 
@@ -43,11 +44,12 @@ var NAVIGATION = {'Overview':    ['#/',            "management"],
                   'Connections': ['#/connections', "management", true],
                   'Channels':    ['#/channels',    "management", true],
                   'Exchanges':   ['#/exchanges',   "management", true],
-                  'Queues':      ['#/queues',      "management", true],
+                  'Queues and Streams': ['#/queues',      "management", true],
                   'Admin':
                     [{'Users':         ['#/users',              "administrator"],
                       'Virtual Hosts': ['#/vhosts',             "administrator"],
                       'Feature Flags': ['#/feature-flags',      "administrator"],
+                      'Deprecated Features': ['#/deprecated-features',      "administrator"],
                       'Policies':      ['#/policies',           "management"],
                       'Limits':        ['#/limits',             "management"],
                       'Cluster':       ['#/cluster-name',       "administrator"]},
@@ -94,6 +96,7 @@ var ALL_COLUMNS =
                    ['mode',  'Mode',      true],
                    ['state', 'State',     true]],
       'Details': [['msgs-unconfirmed', 'Unconfirmed', true],
+                  ['consumer-count',   'Consumer count', false],
                   ['prefetch',         'Prefetch',    true],
                   ['msgs-unacked',     'Unacked',     true]],
       'Transactions': [['msgs-uncommitted', 'Msgs uncommitted', false],
@@ -106,7 +109,8 @@ var ALL_COLUMNS =
                         ['rate-redeliver', 'redelivered',        false],
                         ['rate-ack',       'ack',                true]]},
      'connections':
-     {'Overview': [['user',   'User name', true],
+     {'Overview': [['container_id', 'Container ID', true],
+                   ['user',   'User name', true],
                    ['state',  'State',     true]],
       'Details': [['ssl',            'TLS',      true],
                   ['ssl_info',       'TLS details',    false],
@@ -135,11 +139,11 @@ var ALL_COLUMNS =
                         ['rate-deliver', 'deliver / get', true]]},
      'overview':
      {'Statistics': [['file_descriptors',   'File descriptors',   true],
-                     ['socket_descriptors', 'Socket descriptors', true],
                      ['erlang_processes',   'Erlang processes',   true],
                      ['memory',             'Memory',             true],
                      ['disk_space',         'Disk space',         true]],
       'General': [['uptime',    'Uptime',       true],
+                  ['cores',     'Cores',        true],
                   ['info',      'Info',         true],
                   ['reset_stats',     'Reset stats',        true]]}};
 
@@ -177,7 +181,7 @@ const QUEUE_EXTRA_CONTENT_REQUESTS = [];
 // All help ? popups
 var HELP = {
     'delivery-limit':
-      'The number of allowed unsuccessful delivery attempts. Once a message has been delivered unsuccessfully more than this many times it will be dropped or dead-lettered, depending on the queue configuration.',
+      'The number of allowed unsuccessful delivery attempts. Once a message has been delivered unsuccessfully more than this many times it will be dropped or dead-lettered, depending on the queue configuration. The default is always 20. A value of -1 or lower sets the limit to "unlimited".',
 
     'exchange-auto-delete':
       'If yes, the exchange will delete itself after at least one queue or exchange has been bound to this one, and then all queues or exchanges have been unbound.',
@@ -206,8 +210,8 @@ var HELP = {
     'queue-max-age':
       'How long a message published to a stream queue can live before it is discarded.',
 
-    'queue-stream-max-segment-size-bytes':
-      'Total segment size for stream segments on disk.<br/>(Sets the x-stream-max-segment-size-bytes argument.)',
+    'queue-stream-filter-size-bytes':
+      'Size of the filter data attached to each stream chunk.<br/>(Sets the x-stream-filter-size-bytes argument.)',
 
     'queue-auto-delete':
       'If yes, the queue will delete itself after at least one consumer has connected, and then all consumers have disconnected.',
@@ -219,7 +223,7 @@ var HELP = {
       'Optional replacement routing key to use when a message is dead-lettered. If this is not set, the message\'s original routing key will be used.<br/>(Sets the "<a target="_blank" href="https://rabbitmq.com/dlx.html">x-dead-letter-routing-key</a>" argument.)',
 
     'queue-dead-letter-strategy':
-      'Valid values are <code>at-most-once</code> or <code>at-least-once</code>. It defaults to <code>at-most-once</code>. This setting is understood only by quorum queues. If <code>at-least-once</code> is set, <code>Overflow behaviour</code> must be set to <code>reject-publish</code>. Otherwise, dead letter strategy will fall back to <code>at-most-once</code>.',
+      'Valid values are <code>at-most-once</code> or <code>at-least-once</code>. It defaults to <code>at-most-once</code>. If <code>at-least-once</code> is set, <code>Overflow behaviour</code> must be set to <code>reject-publish</code>. Otherwise, dead letter strategy will fall back to <code>at-most-once</code>.',
 
     'queue-single-active-consumer':
       'If set, makes sure only one consumer at a time consumes from the queue and fails over to another registered consumer in case the active one is cancelled or dies.<br/>(Sets the "<a target="_blank" href="https://rabbitmq.com/consumers.html#single-active-consumer">x-single-active-consumer</a>" argument.)',
@@ -230,14 +234,14 @@ var HELP = {
     'queue-max-age':
       'Sets the data retention for stream queues in time units </br>(Y=Years, M=Months, D=Days, h=hours, m=minutes, s=seconds).<br/>E.g. "1h" configures the stream to only keep the last 1 hour of received messages.</br></br>(Sets the x-max-age argument.)',
 
-    'queue-version':
-      'Set the queue version. Defaults to version 1.<br/>Version 1 has a journal-based index that embeds small messages.<br/>Version 2 has a different index which improves memory usage and performance in many scenarios, as well as a per-queue store for messages that were previously embedded.<br/>(Sets the "x-queue-version" argument.)',
-
     'queue-overflow':
-      'Sets the <a target="_blank" href="https://www.rabbitmq.com/maxlength.html#overflow-behaviour">queue overflow behaviour</a>. This determines what happens to messages when the maximum length of a queue is reached. Valid values are <code>drop-head</code>, <code>reject-publish</code> or <code>reject-publish-dlx</code>. The quorum queue type only supports <code>drop-head</code> and <code>reject-publish</code>.',
+      'Sets the <a target="_blank" href="https://www.rabbitmq.com/maxlength.html#overflow-behaviour">queue overflow behaviour</a>. This determines what happens to messages when the maximum length of a queue is reached. Valid values are <code>drop-head</code>, <code>reject-publish</code> or <code>reject-publish-dlx</code>',
+
+    'quorum-queue-overflow':
+      'Sets the <a target="_blank" href="https://www.rabbitmq.com/maxlength.html#overflow-behaviour">queue overflow behaviour</a>. This determines what happens to messages when the maximum length of a queue is reached. Valid values for quorum queues are <code>drop-head</code> and <code>reject-publish</code>.',
 
     'queue-master-locator':
-       'Set the queue into master location mode, determining the rule by which the queue master is located when declared on a cluster of nodes.<br/>(Sets the "<a target="_blank" href="https://www.rabbitmq.com/ha.html">x-queue-master-locator</a>" argument.)',
+       'Deprecated: please use `queue-leader-locator` instead. <a target="_blank" href="https://www.rabbitmq.com/docs/clustering#replica-placement">Controls which node the queue will be running on.</a>',
 
     'queue-leader-locator':
        'Set the rule by which the queue leader is located when declared on a cluster of nodes. Valid values are <code>client-local</code> (default) and <code>balanced</code>.',
@@ -249,13 +253,19 @@ var HELP = {
        'Set the queue type, determining the type of queue to use: raft-based high availability or classic queue. Valid values are <code>quorum</code> or <code>classic</code>. It defaults to <code>classic</code>. <br/>',
 
     'queue-messages':
-      '<p>Message counts.</p><p>Note that "in memory" and "persistent" are not mutually exclusive; persistent messages can be in memory as well as on disc, and transient messages can be paged out if memory is tight. Non-durable queues will consider all messages to be transient.</p>',
+      '<p>Message counts.</p><p>Note that some messages can be in memory and on disk at the same time.',
+
+    'queue-messages-stream':
+      '<p>Approximate message counts.</p><p>Note that streams store some entries that are not user messages such as offset tracking data which is included in this count. Thus this value will never be completely correct.</p>',
 
     'queue-dead-lettered':
       'Applies to messages dead-lettered with dead-letter-strategy <code>at-least-once</code>.',
 
+    'queue-delivery-limit':
+      'The number of times a message can be returned to this queue before it is dead-lettered (if configured) or dropped.',
+
     'queue-message-body-bytes':
-      '<p>The sum total of the sizes of the message bodies in this queue. This only counts message bodies; it does not include message properties (including headers) or metadata used by the queue.</p><p>Note that "in memory" and "persistent" are not mutually exclusive; persistent messages can be in memory as well as on disc, and transient messages can be paged out if memory is tight. Non-durable queues will consider all messages to be transient.</p><p>If a message is routed to multiple queues on publication, its body will be stored only once (in memory and on disk) and shared between queues. The value shown here does not take account of this effect.</p>',
+      '<p>The sum total of the sizes of the message bodies in this queue. This only counts message bodies; it does not include message properties (including headers) or metadata used by the queue.</p><p>Note that some messages can be in memory and on disk at the same time.</p><p>For classic queues, if a message larger than <code>queue_index_embed_msgs_below</code> (4KB by default) is routed to multiple queues, its body will be stored only once and shared between queues. The value shown here does not take this optimization into account.</p>',
 
     'queue-process-memory':
       'Total memory used by this queue process. This does not include in-memory message bodies (which may be shared between queues and will appear in the global "binaries" memory) but does include everything else.',
@@ -299,34 +309,24 @@ var HELP = {
       </dl>',
 
     'channel-prefetch':
-      'Channel prefetch counts. \
+      'Channel prefetch count.\
        <p> \
-         Each channel can have two prefetch counts: A per-consumer count, which \
-         will limit each new consumer created on the channel, and a global \
-         count, which is shared between all consumers on the channel.\
+         Each channel can have a prefetch count. The prefetch is the number of messages that will be held \
+         by the client. Setting a value of 0 will result in an unlimited prefetch. \
        </p> \
-       <p> \
-         This column shows one, the other, or both limits if they are set. \
-       </p>',
+       ',
 
     'file-descriptors':
       '<p>File descriptor count and limit, as reported by the operating \
       system. The count includes network sockets and file handles.</p> \
-      <p>To optimize disk access RabbitMQ uses as many free descriptors as are \
-      available, so the count may safely approach the limit. \
-      However, if most of the file descriptors are used by sockets then \
-      persister performance will be negatively impacted.</p> \
+      <p>To optimize disk access RabbitMQ uses as many file descriptors as \
+      needed, so the limit must be high enough for safe operation.</p> \
       <p>To change the limit on Unix / Linux, use "ulimit -n". To change \
       the limit on Windows, set the ERL_MAX_PORTS environment variable</p> \
       <p>To report used file handles on Windows, handle.exe from \
       sysinternals must be installed in your path. You can download it \
       <a target="_blank" href="https://technet.microsoft.com/en-us/sysinternals/bb896655">here</a>.</p>',
 
-    'socket-descriptors':
-      'The network sockets count and limit managed by RabbitMQ.<br/> \
-      When the limit is exhausted RabbitMQ will stop accepting new \
-      network connections.',
-
     'memory-alarm':
       '<p>The <a target="_blank" href="https://www.rabbitmq.com/memory.html#memsup">memory \
       alarm</a> for this node has gone off. It will block \
@@ -447,10 +447,6 @@ var HELP = {
         <dd>Rate at which empty queues are hit in response to basic.get.</dd>\
         <dt>Return</dt>\
         <dd>Rate at which basic.return is sent to publishers for unroutable messages published with the \'mandatory\' flag set.</dd>\
-        <dt>Disk read</dt>\
-        <dd>Rate at which queues read messages from disk.</dd>\
-        <dt>Disk write</dt>\
-        <dd>Rate at which queues write messages to disk.</dd>\
       </dl>\
       <p>\
         Note that the last two items originate in queues rather than \
@@ -470,18 +466,6 @@ var HELP = {
 
     'binary-use' : '<p>Binary accounting is not exact; binaries are shared between processes (and thus the same binary might be counted in more than one section), and the VM does not allow us to track binaries that are not associated with processes (so some binary use might not appear at all).</p>',
 
-    'policy-ha-mode' : 'One of <code>all</code> (mirror to all nodes in the cluster), <code>exactly</code> (mirror to a set number of nodes) or <code>nodes</code> (mirror to an explicit list of nodes). If you choose one of the latter two, you must also set <code>ha-params</code>.',
-
-    'policy-ha-params' : 'Absent if <code>ha-mode</code> is <code>all</code>, a number\
-    if <code>ha-mode</code> is <code>exactly</code>, or a list\
-    of strings if <code>ha-mode</code> is <code>nodes</code>.',
-
-    'policy-ha-sync-mode' : 'One of <code>manual</code> or <code>automatic</code>. <a target="_blank" href="https://www.rabbitmq.com/ha.html#unsynchronised-mirrors">Learn more</a>',
-
-    'policy-ha-promote-on-shutdown' : 'One of <code>when-synced</code> or <code>always</code>. <a target="_blank" href="https://www.rabbitmq.com/ha.html#unsynchronised-mirrors">Learn more</a>',
-
-    'policy-ha-promote-on-failure' : 'One of <code>when-synced</code> or <code>always</code>. <a target="_blank" href="https://www.rabbitmq.com/ha.html#unsynchronised-mirrors">Learn more</a>',
-
     'policy-federation-upstream-set' :
     'A string; only if the federation plugin is enabled. Chooses the name of a set of upstreams to use with federation, or "all" to use all upstreams. Incompatible with <code>federation-upstream</code>.',
 
@@ -603,8 +587,40 @@ var HELP = {
         <dd>Rate at which queues are created. Declaring a queue that already exists counts for a "Declared" event, but not for a "Created" event. </dd>\
         <dt>Deleted</dt>\
         <dd>Rate at which queues are deleted.</dd>\
-     </dl> '
+     </dl> ',
 
+    'container-id':
+      'Name of the client application as sent from client to RabbitMQ in the "container-id" field of the AMQP 1.0 <a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-transport-v1.0-os.html#type-open">open</a> frame.',
+
+    'incoming-links':
+      '<a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-transport-v1.0-os.html#section-links">Links</a> where the client is the sender/publisher and RabbitMQ is the receiver of messages.',
+
+    'outgoing-links':
+      '<a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-transport-v1.0-os.html#section-links">Links</a> where the client is the receiver/consumer and RabbitMQ is the sender of messages.',
+
+    'target-address':
+      'The "address" field of the link <a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-messaging-v1.0-os.html#type-target">target</a>.',
+
+    'source-address':
+      'The "address" field of the link <a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-messaging-v1.0-os.html#type-source">source</a>.',
+
+    'amqp-source-queue':
+      'The client receives messages from this queue.',
+
+    'amqp-unconfirmed-messages':
+      'Number of messages that have been sent to queues but have not been confirmed by all queues.',
+
+    'snd-settle-mode':
+      '<a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-transport-v1.0-os.html#type-sender-settle-mode">Sender Settle Mode</a>',
+
+    'sender-settles':
+      '"true" if the sender sends all deliveries settled to the receiver. "false" if the sender sends all deliveries initially unsettled to the receiver.',
+
+    'outgoing-unsettled-deliveries':
+      'Number of messages that have been sent to consumers but have not yet been settled/acknowledged.',
+
+    'amqp-filter':
+      'Filters are predicates that define which messages RabbitMQ sends to the receiver. Each filter in the <a target="_blank" href="https://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-messaging-v1.0-os.html#type-filter-set">Filter Set</a> has a name displayed in the boxes below. Hovering over a box will display the filter descriptor and the filter definition.'
 };
 
 ///////////////////////////////////////////////////////////////////////////
@@ -691,7 +707,7 @@ function DisplayControl() {
   this.vhosts = false
   this.rabbitmqVersions = false
 
-  this.update = function(overview, ui_data_model) {    
+  this.update = function(overview, ui_data_model) {
     this.nodes = ac.canListNodes() && ui_data_model.nodes.length > 1
     this.vhosts = ac.canAccessVhosts()
     this.rabbitmqVersions = false
@@ -708,6 +724,7 @@ function DisplayControl() {
 
 }
 
+
 // Set up the above vars
 function setup_global_vars(overview) {
     rates_mode = overview.rates_mode;
@@ -725,7 +742,7 @@ function setup_global_vars(overview) {
 
     user_name = fmt_escape_html(user.name);
     $('#header #logout').prepend(
-      'User ' + (user_administrator && !oauth.enabled ?  '<a href="#/users/' + user_name + '">' + user_name + '</a>' : user_name)
+      'User ' + (user_administrator && user.is_internal_user ?  '<a href="#/users/' + user_name + '">' + user_name + '</a>' : user_name)
     );
 
     var product = overview.rabbitmq_version;
@@ -876,3 +893,217 @@ var chart_data = {};
 var last_page_out_of_range_error = 0;
 
 var oauth;
+
+
+///////////////////////////////////////////////////////////////////////////
+//                                                                       //
+// Queue types                                                           //
+//                                                                       //
+///////////////////////////////////////////////////////////////////////////
+
+/// this queue types are very well known to the server, at the very least
+/// this collection must be validated in terms of matching server queue
+/// types registry. I hope I will have time for this.
+var QUEUE_TYPE = function (queue) {
+    return QUEUE_TYPE[get_queue_type(queue)];
+}
+// TODO: while this allows for custom queues
+// the proper way is to follow single source of truth
+// and generate most of this on the server from queue type metadata
+// including replacing tmpl's with data-driven generators
+// For example server knows policy_apply_to for each queue
+// and it knows what extra agruments each queue type accepts.
+// So for the latter case we dont' need a template that lists
+// queue args. We need iterator over server-supplied object.
+QUEUE_TYPE["default"] = {
+    label: "Default",
+    params: {},
+    policy_apply_to: "classic_queues",
+    actions: {
+        get_message: true,
+        purge: true
+    },
+    tmpl: {
+        "arguments"    : "classic-queue-arguments",
+        // TODO: this must be generated from js objects of course.
+        // and then those objects must be rendered by the server
+        "user_policy_arguments": "classic-queue-user-policy-arguments",
+        "operator_policy_arguments": "classic-queue-operator-policy-arguments",
+        "list"   : "classic-queue-list",
+        "stats"  : "classic-queue-stats",
+        "node_details" : "classic-queue-node-details"
+    }
+};
+
+QUEUE_TYPE["classic"] = {
+    label: "Classic",
+    params: {},
+    policy_apply_to: "classic_queues",
+    actions: {
+        get_message: true,
+        purge: true
+    },
+    tmpl: {
+        "arguments"    : "classic-queue-arguments",
+        "user_policy_arguments": "classic-queue-user-policy-arguments",
+        "operator_policy_arguments": "classic-queue-operator-policy-arguments",
+        "list"   : "classic-queue-list",
+        "stats"  : "classic-queue-stats",
+        "node_details" : "classic-queue-node-details"
+    }
+};
+
+QUEUE_TYPE["quorum"] = {
+    label: "Quorum",
+    params: {
+        'durable': true,
+        'auto_delete': false
+    },
+    policy_apply_to: "quorum_queues",
+    actions: {
+        get_message: true,
+        purge: true
+    },
+    tmpl: {
+        "arguments"    : "quorum-queue-arguments",
+        "user_policy_arguments": "quorum-queue-user-policy-arguments",
+        "operator_policy_arguments": "quorum-queue-operator-policy-arguments",
+        "list"   : "quorum-queue-list",
+        "stats": "quorum-queue-stats",
+        "node_details" : "quorum-queue-node-details"
+    }
+};
+
+QUEUE_TYPE["stream"] = {
+    label: "Stream",
+    params: {
+        'durable': true,
+        'auto_delete': false
+    },
+    policy_apply_to: "streams",
+    actions: {
+        get_message: false,
+        purge: false
+    },
+    tmpl: {
+        "arguments"    : "stream-queue-arguments",
+        "user_policy_arguments": "quorum-queue-user-policy-arguments",
+        "operator_policy_arguments": "stream-queue-operator-policy-arguments",
+        "list"   : "stream-queue-list",
+        "stats"  : "stream-queue-stats",
+        "node_details" : "stream-queue-node-details"
+    }
+};
+
+// here I'll shortcut for now and let it be like that
+// other queue types can inject themlves where they want.
+// since the 'sections' object will likely keep key insertion
+// order custom keys for queue type will be coming last.
+
+// maybe add helper functions?
+var MEMORY_STATISTICS = {
+    sections: {'queue_procs'         : ['classic',  'Classic queues'],
+               'quorum_queue_procs'  : ['quorum', 'Quorum queues'],
+               'quorum_queue_dlx_procs'      : ['quorum', 'Dead letter workers'],
+               'stream_queue_procs'          : ['stream',  'Stream queues'],
+               'stream_queue_replica_reader_procs'  : ['stream',  'Stream queues (replica reader)'],
+               'stream_queue_coordinator_procs'  : ['stream',  'Stream queues (coordinator)'],
+               'binary'              : ['binary', 'Binaries'],
+               'connection_readers'  : ['conn',   'Connection readers'],
+               'connection_writers'  : ['conn',   'Connection writers'],
+               'connection_channels' : ['conn',   'Connection channels'],
+               'connection_other'    : ['conn',   'Connections (other)'],
+               'mnesia'              : ['table',  'Mnesia'],
+               'msg_index'           : ['table',  'Message store index'],
+               'mgmt_db'             : ['table',  'Management database'],
+               'quorum_ets'          : ['table',  'Quorum queue ETS tables'],
+               'other_ets'           : ['table',  'Other ETS tables'],
+               'plugins'             : ['proc',   'Plugins'],
+               'other_proc'          : ['proc',   'Other process memory'],
+               'code'                : ['system', 'Code'],
+               'atom'                : ['system', 'Atoms'],
+               'other_system'        : ['system', 'Other system'],
+               'allocated_unused'    : ['unused', 'Allocated unused'],
+               'reserved_unallocated': ['unused', 'Unallocated reserved by the OS']},
+    keys: [[{name: 'Classic Queues', colour: 'classic',
+             keys: [['queue_procs',       'queues']]},
+            {name: 'Quorum Queues', colour: 'quorum',
+             keys: [['quorum_queue_procs','quorum'],
+                    ['quorum_queue_dlx_procs', 'dead letter workers']]},
+            {name: 'Streams', colour: 'stream',
+             keys: [['stream_queue_procs',                'stream'],
+                    ['stream_queue_replica_reader_procs', 'stream replica reader'],
+                    ['stream_queue_coordinator_procs',    'stream coordinator']]},
+            {name: 'Binaries', colour: 'binary',
+             keys: [['binary', '']]}],
+
+           [{name: 'Connections', colour: 'conn',
+             keys: [['connection_readers',  'readers'],
+                    ['connection_writers',  'writers'],
+                    ['connection_channels', 'channels'],
+                    ['connection_other',    'other']]}],
+
+           [{name: 'Tables', colour: 'table',
+             keys: [['mnesia',              'internal database tables'],
+                    ['msg_index',           'message store index'],
+                    ['mgmt_db',             'management database'],
+                    ['quorum_ets',          'quorum queue tables'],
+                    ['other_ets',           'other']]}],
+
+           [{name: 'Processes', colour: 'proc',
+             keys: [['plugins',             'plugins'],
+                    ['metadata_store',      'metadata store'],
+                    ['other_proc',          'other']]},
+            {name: 'System', colour: 'system',
+             keys: [['code',                'code'],
+                    ['atom',                'atoms'],
+                    ['other_system',        'other']
+                   ]}],
+
+           [{name: 'Preallocated memory', colour: 'unused',
+             keys: [['allocated_unused',     'preallocated by runtime, unused'],
+                    ['reserved_unallocated', 'unallocated, reserved by the OS']]}]]
+}
+
+var BINARY_STATISTICS = {
+    sections: {'queue_procs'         : ['classic',  'Classic queues'],
+               'quorum_queue_procs'  : ['quorum',  'Quorum queues'],
+               'quorum_queue_dlx_procs'      : ['quorum', 'Dead letter workers'],
+               'stream_queue_procs'          : ['stream',  'Stream queues'],
+               'stream_queue_replica_reader_procs'  : ['stream',  'Stream queues (replica reader)'],
+               'stream_queue_coordinator_procs'  : ['stream',  'Stream queues (coordinator)'],
+               'connection_readers'  : ['conn',   'Connection readers'],
+               'connection_writers'  : ['conn',   'Connection writers'],
+               'connection_channels' : ['conn',   'Connection channels'],
+               'connection_other'    : ['conn',   'Connections (other)'],
+               'msg_index'           : ['table',  'Message store index'],
+               'mgmt_db'             : ['table',  'Management database'],
+               'plugins'             : ['proc',   'Plugins'],
+               'metadata_store'      : ['metadata_store',  'Metadata store'],
+               'other'               : ['system', 'Other binary references']},
+    key: [[{name: 'Classic Queues', colour: 'classic',
+            keys: [['queue_procs',                       'queues']]},
+           {name: 'Quorum Queues', colour: 'quorum',
+            keys: [['quorum_queue_procs',                'quorum'],
+                   ['quorum_queue_dlx_procs',            'dead letter workers']]},
+           {name: 'Streams', colour: 'stream',
+            keys: [['stream_queue_procs',                'stream'],
+                   ['stream_queue_replica_reader_procs', 'stream replica reader'],
+                   ['stream_queue_coordinator_procs',    'stream coordinator']]}],
+
+          [{name: 'Connections', colour: 'conn',
+            keys: [['connection_readers',  'readers'],
+                   ['connection_writers',  'writers'],
+                   ['connection_channels', 'channels'],
+                   ['connection_other',    'other']]}],
+
+          [{name: 'Tables', colour: 'table',
+            keys: [['msg_index',           'message store index'],
+                   ['mgmt_db',             'management database']]}],
+
+          [{name: 'Processes', colour: 'proc',
+            keys: [['plugins',             'plugins'],
+                   ['metadata_store',      'metadata store']]},
+           {name: 'System', colour: 'system',
+            keys: [['other',               'other']]}]]
+};
